当幸福来敲门 (豆瓣)
Description: 当幸福来敲门电影简介和剧情介绍,当幸福来敲门影评、图片、预告片、影讯、论坛、在线购票
Keywords: 当幸福来敲门,The Pursuit of Happyness,当幸福来敲门影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.23豆瓣电影Top250

# 当幸福来敲门 The Pursuit of Happyness (2006)

更新描述或海报

导演: 加布里埃莱·穆奇诺
编剧: 斯蒂夫·康拉德
主演: 威尔·史密斯 / 贾登·史密斯 / 坦迪·牛顿 / 布莱恩·豪威 / 詹姆斯·凯伦 / 丹·卡斯泰兰尼塔 / 柯特·富勒 / 塔卡尤·费舍尔 / 凯文·韦斯特 / 乔治·张 / 戴维·迈克尔·西尔弗曼 / 多米尼克·博夫 / 杰弗·卡伦 / 乔伊芙·拉文 / 斯科特·克拉斯
类型: 剧情 / 家庭 / 传记
制片国家/地区: 美国
语言: 英语 / 粤语
上映日期: 2008-01-17(中国大陆) / 2020-07-20(中国大陆重映) / 2006-12-15(美国)
片长: 117分钟
又名: 寻找快乐的故事(港) / 追求快乐 / 幸福追击 / The Pursuit of Happiness
IMDb: tt0454921
豆瓣评分
引用
9.2
1450218人评价
5星
64.7%
4星
29.2%
3星
5.6%
2星
0.4%
1星
0.1%
好友评分
你关注的人看过这部作品的平均分
9.6
5人评价
好于 99% 家庭片
好于 99% 剧情片
我看过这部电影 2020-07-15 修改
我的评价:
推荐

## 当幸福来敲门的剧情简介 · · · · · ·

克里斯•加纳（威尔·史密斯 Will Smith 饰）用尽全部积蓄买下了高科技治疗仪，到处向医院推销，可是价格高昂，接受的人不多。就算他多努力都无法提供一个良好的生活环境给妻儿，妻子（桑迪·牛顿 Thandie Newton 饰）最终选择离开家。从此他带着儿子克里斯托夫（贾登·史密斯 Jaden Smith 饰）相依为命。克里斯好不容易争取回来一个股票投资公司实习的机会，就算没有报酬，成功机会只有百分之五，他仍努力奋斗，儿子是他的力量。他看尽白眼，与儿子躲在地铁站里的公共厕所里，住在教堂的收容所里…… 他坚信，幸福明天就会来临。 ©豆瓣

## 当幸福来敲门的演职员 · · · · · · ( 全部 79 )

- 加布里埃莱·穆奇诺 导演
- 威尔·史密斯 饰 Chris Gardner
- 贾登·史密斯 饰 Christopher
- 坦迪·牛顿 饰 Linda
- 布莱恩·豪威 饰 Jay Twistle
- 詹姆斯·凯伦 饰 Martin Frohm

## 当幸福来敲门的视频和图片 · · · · · · ( 预告片1 | 视频评论1 · 添加 | 图片403 · 添加 )

## 当幸福来敲门的获奖情况 · · · · · · ( 全部 )

- 第79届奥斯卡金像奖
- 最佳男主角(提名)
- 威尔·史密斯

- 第64届金球奖
- 电影类 剧情片最佳男主角(提名)
- 威尔·史密斯

- 第16届MTV电影奖
- MTV电影奖 最佳表演(提名)
- 威尔·史密斯

## 喜欢这部电影的人也喜欢 · · · · · ·

  阿甘正传

  肖申克的救赎

  摔跤吧！爸爸

  三傻大闹宝莱坞

  贫民窟的百万富翁

  荒岛余生

  心灵捕手

  国王的演讲

  饮食男女

  叫我第一名

我要写短评

## 当幸福来敲门的短评 · · · · · · ( 全部 236959 条 )

热门 / 最新 / 好友

### 5336 有用 囍夭夭 看过 2009-04-06 20:40:29

看到开头就知道结局，不过这并不重要，重要的是过程。。。最感人的不是赢得职位，而是在厕所里捂住儿子的耳朵。。。作为一名容易感情用事的中国观众，感动比励志对我来说更重要=。=

### 6410 有用 Zia 看过 2009-08-09 19:33:17

如果能让自己不再为光阴被虚度，才华被耗尽而流泪，如果能让自己坚定，“我不要似是而非的人生，我要自己做的每一件事都刻骨铭心”，那么这场狂热便是得其所，记住这永远不是最差的人生。

### 3155 有用 水木丁 看过 2015-03-08 15:31:34

虽然是个好莱坞励志片，但真正让我感慨的其实是，穷人想要翻身，真是太难太难了，他们大多数不是不努力工作，但确实是一根绳子勒在脖子上，压根没有喘息的机会，而且他们的孩子从出生下来就没有，毕竟不是每个穷人家的孩子，都足够幸运能有这么顽强，比别人聪明十倍的爸爸啊。

### 2646 有用 Song³ 看过 2009-03-05 20:38:22

There is no "why" in happiness, there is an "I". 里面励志的桥段很多，比如打篮球时候威尔对他儿子说的话。这是中国父母需要学到的...尽可能地给孩子一个美好的世界。

### 2329 有用 疤疤爸爸 看过 2009-08-23 12:15:59

为毛不去天桥上乞讨？为毛不去地铁里乞讨？在我们这儿是这么办的。

> 更多短评 236959条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。

### 0 有用 CoCo陶可可 看过 2020-03-15 14:01:07

2020，011。

我要写影评

## 当幸福来敲门的影评 · · · · · · ( 全部 4745 条 )

热门 / 最新 / 好友
ida 2008-05-24 19:11:48

## 人生中，比较惨白的那一部分

（本文剧透，阅读须谨慎……） 一段时间以前，一位在港的大陆学生，因为学业的压力、前途的渺茫等诸多原因，选择了自杀。在讨论和反思的潮流中，有一位毕业生在校内网匿名发表了自己的故事。他说，自己当年在学校也曾经面临绝境，一文不名。他选择了做“乞丐学生”，坚持... (展开)
4181 203 544回应 收起
张樾 2008-02-17 09:53:46

## 总会找到一个上帝，端坐天堂

片子中有个关于上帝的笑话是这样的：一个虔诚的落水者希望上帝能救他。一艘船过去了，他拒绝被救，说，上帝会来救我的。第二艘船又过去，他仍然以同样的理由拒绝被救。后来落水者溺死了。天堂上，他不服气问上帝，万能的主啊，你为什么不来救我？上帝回答道，为了救你，我派出... (展开)
3553 114 276回应 收起
铂程斋@喷嚏网 2009-06-04 17:09:26

## 在路上

（一） 罗永浩在吉大做了一个演讲，叫《我的奋斗》。其中，有一个他早年在新东方学习英语的故事。 他们学习的地方，在北京附近的一个山上。很多人象疯子一样拼命地背单词。他觉得这种疯狂的感觉真好。 他经常在晚上2点过离去的时候，还有很多人在坚持。 有一天，他决... (展开)
2536 119 233回应 收起
cathystour 2007-12-21 23:50:08

## There Is No “Y” In Happiness, There Is “I”

今天又看了一个关于loser的故事。其实我一直觉得英语loser要比中文里的“失败者”严重得多，当你被冠以一个“loser”的名号，你就要抬不起头来；要是你被人称作“total loser”的时候，恐怕你这辈子都不要想翻身了。 但这个故事无关乎成功，只关乎幸福。 唐人街料... (展开)
1058 38 125回应 收起
Pin 2007-02-19 15:10:34

## 幸福的瞬间——关于《当幸福来敲门》

年三十清晨，我翻出《当幸福来敲门》这部片子，默默开始看。 电影里没有漂亮的演员,没有花哨的剪辑,也没有精彩的配乐……但是却有一个好故事，一个足以令我坐在电脑面前看完并为之感动的好故事。 励志题材的故事大概都是这个模式：窘迫的处境，艰难的奋斗，没完没了的倒霉事... (展开)
1006 57 157回应 收起
neo 2009-11-20 00:05:18

## “励志”其实是骗人的把戏

在朋友的推荐下看了这部电影，我竟然没有多大的感触，也许我太邪恶了。 主人公天生就很聪明，可以说是鹤立群鸡，只是他不懂的利用自己的智慧。主人公在别人脸上总是看到微笑，而自己总是为各种事情愁眉苦脸。 据说这部电影改编自自传，也许是作者（主人公）本人的心态有问题才... (展开)
363 127 148回应 收起
Vermouth 2007-04-14 19:58:30

## 其实幸福不会来敲门

感动。 在父子俩在餐厅里坐着，看着远处一家人快乐的吃饭的时候。修好的机器亮起了灯，明亮的就像是来自天堂。chris红了眼圈，和上司们一一握手，然后冲出去，冲到幼儿园，抱起他的儿子。 所以他生活的这一部分，这一小部分，叫做幸福。 诚如人人都偶尔会犯傻会火星一样，人人... (展开)
306 32 65回应 收起
溜溜 2009-02-26 19:02:37

## 没有一颗心，会因为追求梦想而受伤害

你是在什么状态下看这部电影的？ 是和恋人手拉着手在电影院甜蜜共享，还是一个人宅在昏暗的房间里独自欣赏？ 是下了班拖着疲惫的身躯回家随意看看，还是和同样郁闷的朋友相约一起寻找安慰？ 我们中的大多数，终日在钢筋混凝土的城市森林里打转，每天踩着时间点做该做的事情，生... (展开)
231 15 46回应 收起
浅执 2015-04-23 09:52:23

## 所谓的“幸福”幻梦

这篇影评可能有剧透

看豆瓣是一片叫好，不过有些话还是不吐不快。 15年牛市我是找和股票相关的电影找到的这个片子虽然和股票的关系不大但还是耐着性子看完。看完我就两个字：失望。我不知道影片到底讲了些什么，这是部励志剧？还是悲剧？或者说其实是反讽。全片讲述了男主人公的悲惨际遇为了生活疲... (展开)
122 15 36回应 收起

> 更多影评 4745篇

添加新讨论

## 讨论区 · · · · · ·

这片被中国市场严重高估？ | 来自逃避可耻还没用 | 29 回应 | 2022-11-23 17:56:14
幸福，真的会来吗？ | 来自Hell Angel |  | 2022-11-23 14:41:24
对男主喜欢不起来 | 来自小-放-羊 | 2 回应 | 2022-11-15 12:57:50
男主的骨密度扫描仪一而再地失而复得挺刻意的 | 来自多宝鱼 | 13 回应 | 2022-11-12 18:41:05
给美国底层黑人喝的一碗毒鸡汤 | 来自墨九毓 | 56 回应 | 2022-11-08 23:45:07

> 去这部影片的讨论区（全部744条）

## 关于《当幸福来敲门》的问题 · · · · · · ( 全部19个 )

- 为啥很多故事简单却真实感人的电影更容易获得高分？ 9人回答
- 视频影评【珠元宝影评】当幸福来敲门，大家觉得如何？ 1人回答

> 全部19个问题

## 在哪儿看这部电影 · · · · · ·

报错

- 腾讯视频 VIP免费观看
- 1905电影网 VIP免费观看
- 哔哩哔哩 单片付费

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 【内牛满面】 (影志)
- 【励志电影】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 经典商业与法律电影 (passionfly)

## 谁在看这部电影 · · · · · ·

- leon希尔江
  刚刚 想看
- 新仁格
  1分钟前 看过
- 豆友ybOh3RsK-w
  2分钟前 看过

2727330人看过 / 328344人想看

订阅当幸福来敲门的评论:
feed: rss 2.0